@@ -15,11 +15,11 @@ from ovito.pipeline import ModifierInterface
 from ovito.modifiers import ColorByTypeModifier
 from traits.api import Bool, Code, Instance
 from ovito.traits import *
-from ovito.traits import *
 import numpy.typing as npt
 from typing import Any, List
 from collections import namedtuple
 from abc import abstractmethod
+import copy
 
 RegionRotation = namedtuple("rotation", ["theta", "px", "py", "pz", "rx", "ry", "rz"])
 
@@ -133,7 +133,7 @@ class RegionStyle:
         mesh.regions_.count += 1
         mesh.regions_['Region ID_'][-1] = mesh.regions.count
         # LAMMPS region IDs should be unique
-        existing_region_id = mesh.regions['Region ID'].type_by_name(self.region_id, raise_error=False)
+        existing_region_id = mesh.regions['Region ID'].type_by_name(self.region_id, require=False)
         if existing_region_id:
             print(f"Warning: Region ID '{self.region_id}' already exists in the output mesh (numeric id {existing_region_id.id}). Consider renaming it.")
         region_type = mesh.regions_['Region ID_'].add_type_id(mesh.regions.count, mesh.regions, self.region_id)
@@ -161,7 +161,7 @@ class RegionStyle:
             faces += new_vertex_index
         new_face_index = mesh.create_faces(faces)
         # Set 'Region' property of new faces
-        mesh.faces["Region_"][new_face_index:] = mesh.regions.count - 1
+        mesh.faces_["Region"][new_face_index:] = mesh.regions.count - 1
 
     @abstractmethod
     def generate_verts_and_faces(self, domain: SimulationCell):
@@ -609,7 +609,6 @@ class Sphere(RegionStyle):
                         edge1 = vertices[second]
                         point = np.asarray(edge1) + np.asarray(edge0)
                         point /= np.linalg.norm(point)
-                        point /= np.linalg.norm(point)
                         vertices.append(point)
                         new_vertex_cache[key] = len(vertices) - 1
                     mid[edge] = new_vertex_cache[key]
@@ -766,19 +765,15 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
 
     """
 
-    commands = Code(value='region 1 sphere -20 0 0 15\nregion 2 cylinder z 10 0 5 INF INF', label='', ovito_group='Region commands')
-    commands = Code(value='region 1 sphere -20 0 0 15\nregion 2 cylinder z 10 0 5 INF INF', label='', ovito_group='Region commands')
+    commands: str = Code(value='region 1 sphere -20 0 0 15\nregion 2 cylinder z 10 0 5 INF INF', label='', ovito_group='Region commands')
     """
     The `LAMMPS region command(s) <https://docs.lammps.org/region.html>`__ to be interpreted by the modifier.
-    The `LAMMPS region command(s) <https://docs.lammps.org/region.html>`__ to be interpreted by the modifier.
     If multiple commands are specified, they must be separated by new-line characters.
 
-    :Default: ``'region 1 sphere -20 0 0 15'``
     :Default: ``'region 1 sphere -20 0 0 15'``
     """
 
-    color_by_type = Bool(default_value=False, label='Color by region', ovito_group='Options')
-    color_by_type = Bool(default_value=False, label='Color by region', ovito_group='Options')
+    color_by_region: bool = Bool(default_value=False, label='Color by region', ovito_group='Options')
     """
     Controls whether the modifier should color the parts of the surface mesh by region.
     The effect of this option is the same as if you would additionally insert the :py:class:`~ovito.modifiers.ColorByTypeModifier` into the pipeline.
@@ -786,15 +781,6 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
     If turned off, the mesh will have a uniform color by default and you can make use of the color mapping options of the :py:attr:`vis` element
     to configure a different coloring scheme if necessary.
 
-    If turned on, the modifier will generate the :ref:`mesh region property <surface-mesh-region-properties-list>` ``Color``,
-    and the mesh will be rendered using the values stored in this property. The modifier assigns a prescribed set of colors to the regions
-    in a cyclic manner.
-    Controls whether the modifier should color the parts of the surface mesh by region.
-    The effect of this option is the same as if you would additionally insert the :py:class:`~ovito.modifiers.ColorByTypeModifier` into the pipeline.
-
-    If turned off, the mesh will have a uniform color by default and you can make use of the color mapping options of the :py:attr:`vis` element
-    to configure a different coloring scheme if necessary.
-
     If turned on, the modifier will generate the :ref:`mesh region property <surface-mesh-region-properties-list>` ``Color``,
     and the mesh will be rendered using the values stored in this property. The modifier assigns a prescribed set of colors to the regions
     in a cyclic manner.
@@ -802,16 +788,18 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
     :Default: ``False``
 
     .. versionadded:: 3.10.0
+
+    .. versionchanged:: 3.11.0 Renamed from :py:attr:`!color_by_type`
     """
 
-    select_atoms = Bool(default_value=False, label='Select interior particles', ovito_group='Options')
+    select_atoms: bool = Bool(default_value=False, label='Select interior particles', ovito_group='Options')
     """
     Turns on the selection of all particles that are located within any of the generated regions.
 
     :Default: ``False``
     """
 
-    vis = OvitoObjectTrait(SurfaceMeshVis, title='LAMMPS Regions', smooth_shading=False, clip_at_domain_boundaries=True)
+    vis: SurfaceMeshVis = OvitoObject(SurfaceMeshVis, title='LAMMPS Regions', smooth_shading=False, clip_at_domain_boundaries=True)
     """
     The :py:class:`~ovito.vis.SurfaceMeshVis` element that is responsible for rendering the surface mesh generated by the modifier.
     It controls the visual appearance of the region surfaces.
@@ -825,16 +813,13 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
         if 'lammps-regions' not in data.surfaces:
 
             # Disable PBCs for the surface mesh domain.
-            # Note: For the time being, we have to clone the entire DataCollection, because the Python API has no way of copying just the SimulationCell object.
-            copy = data.clone()
-            copy.cell_.pbc = (False, False, False)
-            copy.cell_.vis = None
-            copy.cell_.vis = None
+            open_cell = copy.deepcopy(data.cell)
+            open_cell.pbc = (False, False, False)
+            open_cell.vis = None
 
-            surface_mesh = data.surfaces.create('lammps-regions', domain=copy.cell, title='LAMMPS Regions', vis=self.vis)
+            surface_mesh = data.surfaces.create('lammps-regions', domain=open_cell, title='LAMMPS Regions', vis=self.vis)
         else:
-            surface_mesh = data.surfaces['lammps-regions']
-            surface_mesh = data.surfaces['lammps-regions']
+            surface_mesh = data.surfaces['lammps-regions_']
         if 'Region ID' not in surface_mesh.regions:
             surface_mesh.regions_.create_property('Region ID', components=1, dtype=int)
         if "Region" not in surface_mesh.faces:
@@ -846,15 +831,12 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
         for command in self.cleanup_input(self.commands):
             region = self.parse_region_command(str(command))
             region.generate_mesh(surface_mesh)
-            region.generate_mesh(surface_mesh)
             if self.select_atoms:
                 np.logical_or(sel, region.is_inside(data.particles.positions), out=sel[...])
         surface_mesh.connect_opposite_halfedges()
 
         # Color mesh faces by region type
-        if self.color_by_type:
-            data.apply(ColorByTypeModifier(property = 'Region ID', operate_on = 'regions:lammps-regions/regions'))
-        if self.color_by_type:
+        if self.color_by_region:
             data.apply(ColorByTypeModifier(property = 'Region ID', operate_on = 'regions:lammps-regions/regions'))
 
     def parse_region_command(self, command: str):
@@ -874,10 +856,9 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
         return supported_region_styles[style_name](tokens)
 
     def cleanup_input(self, code: str):
-        code = code.strip()
         code = code.strip()
         lines = []
-        input = iter(code.split("\n"))
+        input = iter([line for line in code.split("\n") if line])
         line = next(input).strip()
         while line:
             l = line
